﻿using Prism.Commands;
using Prism.Mvvm;
using Prism.Regions;

namespace TestProject.ViewModels
{
    /// <summary>
    /// 메인 윈도우 뷰 모델
    /// </summary>
    public class MainWindowViewModel : BindableBase
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 영역 관리자 인터페이스
        /// </summary>
        private readonly IRegionManager regionManager;

        /// <summary>
        /// 제목
        /// </summary>
        private string title = "IRegionManager 인터페이스 : RequestNavigate 메소드를 사용해 영역 탐색하기";

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 제목 - Title

        /// <summary>
        /// 제목
        /// </summary>
        public string Title
        {
            get
            {
                return this.title;
            }
            set
            {
                SetProperty(ref this.title, value);
            }
        }

        #endregion
        #region 탐색하기 명령 - NavigateCommand

        /// <summary>
        /// 탐색하기 명령
        /// </summary>
        public DelegateCommand<string> NavigateCommand { get; private set; }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindowViewModel(regionManager)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="regionManager">영역 관리자 인터페이스</param>
        public MainWindowViewModel(IRegionManager regionManager)
        {
            this.regionManager = regionManager;

            NavigateCommand = new DelegateCommand<string>(Navigate);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 탐색하기 - Navigate(navigatePath)

        /// <summary>
        /// 탐색하기
        /// </summary>
        /// <param name="navigatePath">탐색 경로</param>
        private void Navigate(string navigatePath)
        {
            if(navigatePath != null)
            {
                this.regionManager.RequestNavigate("ContentRegion", navigatePath);
            }
        }

        #endregion
    }
}